Method: ActiveModel::AttributeMethods::ClassMethods#attribute_method_affix

Defined in:
lib/active_model/attribute_methods.rb

#attribute_method_affix(*affixes) ⇒ Object

Declares a method available for all attributes with the given prefix and suffix. Uses method_missing and respond_to? to rewrite the method.

#{prefix}#{attr}#{suffix}(*args, &block)

to

#{prefix}attribute#{suffix}(#{attr}, *args, &block)

An #{prefix}attribute#{suffix} instance method must exist and accept at least the attr argument.

class Person
  include ActiveModel::AttributeMethods

  attr_accessor :name
  attribute_method_affix prefix: 'reset_', suffix: '_to_default!'
  define_attribute_methods :name

  private

  def reset_attribute_to_default!(attr)
    send("#{attr}=", 'Default Name')
  end
end

person = Person.new
person.name                         # => 'Gem'
person.reset_name_to_default!
person.name                         # => 'Default Name'


179
180
181
182
# File 'lib/active_model/attribute_methods.rb', line 179

def attribute_method_affix(*affixes)
  self.attribute_method_matchers += affixes.map! { |affix| AttributeMethodMatcher.new prefix: affix[:prefix], suffix: affix[:suffix] }
  undefine_attribute_methods
end