Method: ActiveModel::Conversion#to_partial_path

Defined in:
lib/active_model/conversion.rb

#to_partial_pathObject

Returns a string identifying the path associated with the object. ActionPack uses this to find a suitable partial to represent the object.

class Person
  include ActiveModel::Conversion
end

person = Person.new
person.to_partial_path # => "people/person"


77
78
79
# File 'lib/active_model/conversion.rb', line 77

def to_partial_path
  self.class._to_partial_path
end