Module: ActiveModel::Dirty

Extended by:
ActiveSupport::Concern
Includes:
AttributeMethods
Defined in:
lib/active_model/dirty.rb

Overview

Active Model Dirty

Provides a way to track changes in your object in the same way as Active Record does.

The requirements to implement ActiveModel::Dirty are to:

  • include ActiveModel::Dirty in your object
  • Call define_attribute_methods passing each method you want to track
  • Call attr_name_will_change! before each change to the tracked attribute

If you wish to also track previous changes on save or update, you need to add

@previously_changed = changes

inside of your save or update method.

A minimal implementation could be:

class Person

include ActiveModel::Dirty

define_attribute_methods [:name]

def name
  @name
end

def name=(val)
  name_will_change! unless val == @name
  @name = val
end

def save
  @previously_changed = changes
  @changed_attributes.clear
end

end

Examples:

A newly instantiated object is unchanged:

person = Person.find_by_name('Uncle Bob')
person.changed?       # => false

Change the name:

person.name = 'Bob'
person.changed?       # => true
person.name_changed?  # => true
person.name_was       # => 'Uncle Bob'
person.name_change    # => ['Uncle Bob', 'Bob']
person.name = 'Bill'
person.name_change    # => ['Uncle Bob', 'Bill']

Save the changes:

person.save
person.changed?       # => false
person.name_changed?  # => false

Assigning the same value leaves the attribute unchanged:

person.name = 'Bill'
person.name_changed?  # => false
person.name_change    # => nil

Which attributes have changed? person.name = 'Bob' person.changed # => ['name'] person.changes # => { 'name' => ['Bill', 'Bob'] }

If an attribute is modified in-place then make use of [attribute_name]_will_change! to mark that the attribute is changing. Otherwise ActiveModel can't track changes to in-place attributes.

person.name_will_change!
person.name << 'y'
person.name_change    # => ['Bill', 'Billy']

Constant Summary

Constants included from AttributeMethods

AttributeMethods::COMPILABLE_REGEXP

Instance Method Summary collapse

Methods included from AttributeMethods

#method_missing, #respond_to?, #respond_to_without_attributes?

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class ActiveModel::AttributeMethods

Instance Method Details

#changedObject

List of attributes with unsaved changes. person.changed # => [] person.name = 'bob' person.changed # => ['name']



109
110
111
# File 'lib/active_model/dirty.rb', line 109

def changed
  changed_attributes.keys
end

#changed?Boolean

Do any attributes have unsaved changes? person.changed? # => false person.name = 'bob' person.changed? # => true

Returns:

  • (Boolean)


101
102
103
# File 'lib/active_model/dirty.rb', line 101

def changed?
  !changed_attributes.empty?
end

#changed_attributesObject

Map of change attr => original value.



131
132
133
# File 'lib/active_model/dirty.rb', line 131

def changed_attributes
  @changed_attributes ||= {}
end

#changesObject

Map of changed attrs => [original value, new value]. person.changes # => {} person.name = 'bob' person.changes # => { 'name' => ['bill', 'bob'] }



117
118
119
# File 'lib/active_model/dirty.rb', line 117

def changes
  changed.inject(HashWithIndifferentAccess.new){ |h, attr| h[attr] = attribute_change(attr); h }
end

#previous_changesObject

Map of attributes that were changed when the model was saved. person.name # => 'bob' person.name = 'robert' person.save person.previous_changes # => => ['bob, 'robert']



126
127
128
# File 'lib/active_model/dirty.rb', line 126

def previous_changes
  @previously_changed
end