Module: ActiveModel::Serializers::Xml

Extended by:
ActiveSupport::Concern
Includes:
ActiveModel::Serialization
Defined in:
lib/active_model/serializers/xml.rb

Overview

Active Model XML Serializer

Defined Under Namespace

Classes: Serializer

Instance Method Summary collapse

Methods included from ActiveModel::Serialization

#serializable_hash

Instance Method Details

#from_xml(xml) ⇒ Object

Sets the model attributes from a JSON string. Returns self.

class Person
include ActiveModel::Serializers::Xml

attr_accessor :name, :age, :awesome

def attributes=(hash)
  hash.each do |key, value|
    instance_variable_set("@#{key}", value)
  end
end

def attributes
  instance_values
end
end

xml = { name: 'bob', age: 22, awesome:true }.to_xml
person = Person.new
person.from_xml(xml) # => #<Person:0x007fec5e3b3c40 @age=22, @awesome=true, @name="bob">
person.name          # => "bob"
person.age           # => 22
person.awesome       # => true


232
233
234
235
# File 'lib/active_model/serializers/xml.rb', line 232

def from_xml(xml)
  self.attributes = Hash.from_xml(xml).values.first
  self
end

#to_xml(options = {}, &block) ⇒ Object

Returns XML representing the model. Configuration can be passed through options.

Without any options, the returned XML string will include all the model's attributes.

user = User.find(1)
user.to_xml
1 David 16 2011-01-30T22:29:23Z

The :only and :except options can be used to limit the attributes included, and work similar to the attributes method.

To include the result of some method calls on the model use :methods.

To include associations use :include.

For further documentation, see ActiveRecord::Serialization#to_xml



204
205
206
# File 'lib/active_model/serializers/xml.rb', line 204

def to_xml(options = {}, &block)
  Serializer.new(self, options).serialize(&block)
end