Method: ActiveModel::Validations::HelperMethods#validates_acceptance_of
- Defined in:
- lib/active_model/validations/acceptance.rb
#validates_acceptance_of(*attr_names) ⇒ Object
Encapsulates the pattern of wanting to validate the acceptance of a terms of service check box (or similar agreement). Example:
class Person < ActiveRecord::Base
validates_acceptance_of :terms_of_service
validates_acceptance_of :eula, :message => "must be abided"
end
If the database column does not exist, the terms_of_service attribute
is entirely virtual. This check is performed only if terms_of_service
is not nil and by default on save.
Configuration options:
- :message - A custom error message (default is: "must be accepted").
- :on - Specifies when this validation is active (default is :save, other options are :create and :update).
- :allow_nil - Skip validation if attribute is
nil(default is true). - :accept - Specifies value that is considered accepted.
The default value is a string "1", which makes it easy to relate to
an HTML checkbox. This should be set to
trueif you are validating a database column, since the attribute is typecast from "1" totruebefore validation. - :if - Specifies a method, proc or string to call to determine if the validation should occur (e.g. :if => :allow_validation, or :if => Proc.new { |user| user.signup_step > 2 }). The method, proc or string should return or evaluate to a true or false value.
- :unless - Specifies a method, proc or string to call to determine if the validation should not occur (for example, :unless => :skip_validation, or :unless => Proc.new { |user| user.signup_step <= 2 }). The method, proc or string should return or evaluate to a true or false value.
63 64 65 |
# File 'lib/active_model/validations/acceptance.rb', line 63 def validates_acceptance_of(*attr_names) validates_with AcceptanceValidator, _merge_attributes(attr_names) end |