Method: ActiveModel::Validations::HelperMethods#validates_exclusion_of
- Defined in:
- lib/active_model/validations/exclusion.rb
#validates_exclusion_of(*attr_names) ⇒ Object
Validates that the value of the specified attribute is not in a particular enumerable object.
class Person < ActiveRecord::Base
validates_exclusion_of :username, :in => %w( admin superuser ), :message => "You don't belong here"
validates_exclusion_of :age, :in => 30..60, :message => "This site is only for under 30 and over 60"
validates_exclusion_of :format, :in => %w( mov avi ), :message => "extension %{value} is not allowed"
end
Configuration options:
-
:in- An enumerable object of items that the value shouldn’t be part of. -
:message- Specifies a custom error message (default is: “is reserved”). -
:allow_nil- If set to true, skips this validation if the attribute isnil(default isfalse). -
:allow_blank- If set to true, skips this validation if the attribute is blank (default isfalse). -
:if- Specifies a method, proc or string to call to determine if the validation should occur (e.g.:if => :allow_validation, or:if => Proc.new { |user| user.signup_step > 2 }). The method, proc or string should return or evaluate to a true or false value. -
:unless- Specifies a method, proc or string to call to determine if the validation should not occur (e.g.:unless => :skip_validation, or:unless => Proc.new { |user| user.signup_step <= 2 }). The method, proc or string should return or evaluate to a true or false value.
38 39 40 |
# File 'lib/active_model/validations/exclusion.rb', line 38 def validates_exclusion_of(*attr_names) validates_with ExclusionValidator, _merge_attributes(attr_names) end |