Method: ActiveModel::Validations::HelperMethods#validates_format_of
- Defined in:
- lib/active_model/validations/format.rb
#validates_format_of(*attr_names) ⇒ Object
Validates whether the value of the specified attribute is of the correct form, going by the regular expression provided.You can require that the attribute matches the regular expression:
class Person < ActiveRecord::Base
validates_format_of :email, with: /\A([^@\s]+)@((?:[-a-z0-9]+\.)+[a-z]{2,})\z/i, on: :create
end
Alternatively, you can require that the specified attribute does not match the regular expression:
class Person < ActiveRecord::Base
validates_format_of :email, without: /NOSPAM/
end
You can also provide a proc or lambda which will determine the regular expression that will be used to validate the attribute.
class Person < ActiveRecord::Base
# Admin can have number as a first letter in their screen name
validates_format_of :screen_name,
with: ->(person) { person.admin? ? /\A[a-z0-9][a-z0-9_\-]*\z/i : /\A[a-z][a-z0-9_\-]*\z/i }
end
Note: use \A and \Z to match the start and end of the string, ^ and $ match the start/end of a line.
Due to frequent misuse of ^ and $, you need to pass the multiline: true option in case you use any of these two anchors in the provided regular expression. In most cases, you should be using \A and \z.
You must pass either :with or :without as an option. In addition, both must be a regular expression or a proc or lambda, or else an exception will be raised.
Configuration options:
-
:message- A custom error message (default is: “is invalid”). -
:allow_nil- If set to true, skips this validation if the attribute isnil(default isfalse). -
:allow_blank- If set to true, skips this validation if the attribute is blank (default isfalse). -
:with- Regular expression that if the attribute matches will result in a successful validation. This can be provided as a proc or lambda returning regular expression which will be called at runtime. -
:without- Regular expression that if the attribute does not match will result in a successful validation. This can be provided as a proc or lambda returning regular expression which will be called at runtime. -
:multiline- Set to true if your regular expression contains anchors that match the beginning or end of lines as opposed to the beginning or end of the string. These anchors are^and$.
There is also a list of default options supported by every validator: :if, :unless, :on and :strict. See ActiveModel::Validation#validates for more information
110 111 112 |
# File 'lib/active_model/validations/format.rb', line 110 def validates_format_of(*attr_names) validates_with FormatValidator, _merge_attributes(attr_names) end |