Method: ActiveModel::AttributeMethods::ClassMethods#attribute_method_suffix
- Defined in:
- lib/active_model/attribute_methods.rb
#attribute_method_suffix(*suffixes) ⇒ Object
Declares a method available for all attributes with the given suffix. Uses method_missing and respond_to? to rewrite the method.
#{attr}#{suffix}(*args, &block)
to
attribute#{suffix}(#{attr}, *args, &block)
An attribute#{suffix} instance method must exist and accept at least the attr argument.
class Person
include ActiveModel::AttributeMethods
attr_accessor :name
attribute_method_suffix '_short?'
define_attribute_methods :name
private
def attribute_short?(attr)
send(attr).length < 5
end
end
person = Person.new
person.name = 'Bob'
person.name # => "Bob"
person.name_short? # => true
143 144 145 146 |
# File 'lib/active_model/attribute_methods.rb', line 143 def attribute_method_suffix(*suffixes) self.attribute_method_matchers += suffixes.map! { |suffix| AttributeMethodMatcher.new suffix: suffix } undefine_attribute_methods end |