Method: ActiveModel::Validations::HelperMethods#validates_format_of
- Defined in:
- lib/active_model/validations/format.rb
#validates_format_of(*attr_names) ⇒ Object
Validates whether the value of the specified attribute is of the correct form, going by the regular expression provided. You can require that the attribute matches the regular expression:
class Person < ActiveRecord::Base
validates_format_of :email, :with => /\A([^@\s]+)@((?:[-a-z0-9]+\.)+[a-z]{2,})\Z/i, :on => :create
end
Alternatively, you can require that the specified attribute does not match the regular expression:
class Person < ActiveRecord::Base
validates_format_of :email, :without => /NOSPAM/
end
Note: use \A and \Z to match the start and end of the string, ^ and $ match the start/end of a line.
You must pass either :with or :without as an option. In addition, both must be a regular expression, or else an exception will be raised.
Configuration options:
-
:message- A custom error message (default is: “is invalid”). -
:allow_nil- If set to true, skips this validation if the attribute isnil(default isfalse). -
:allow_blank- If set to true, skips this validation if the attribute is blank (default isfalse). -
:with- Regular expression that if the attribute matches will result in a successful validation. -
:without- Regular expression that if the attribute does not match will result in a successful validation. -
:on- Specifies when this validation is active (default is:save, other options:create,:update). -
:if- Specifies a method, proc or string to call to determine if the validation should occur (e.g.:if => :allow_validation, or:if => Proc.new { |user| user.signup_step > 2 }). The method, proc or string should return or evaluate to a true or false value. -
:unless- Specifies a method, proc or string to call to determine if the validation should not occur (e.g.:unless => :skip_validation, or:unless => Proc.new { |user| user.signup_step <= 2 }). The method, proc or string should return or evaluate to a true or false value.
61 62 63 |
# File 'lib/active_model/validations/format.rb', line 61 def validates_format_of(*attr_names) validates_with FormatValidator, _merge_attributes(attr_names) end |