Method: ActiveModel::Validations::HelperMethods#validates_numericality_of
- Defined in:
- lib/active_model/validations/numericality.rb
#validates_numericality_of(*attr_names) ⇒ Object
Validates whether the value of the specified attribute is numeric by
trying to convert it to a float with Kernel.Float (if only_integer
is false) or applying it to the regular expression /\A[+-]?\d+\Z/
(if only_integer is set to true).
class Person < ActiveRecord::Base
validates_numericality_of :value, on: :create
end
Configuration options:
- :message - A custom error message (default is: "is not a number").
- :only_integer - Specifies whether the value has to be an
integer, e.g. an integral value (default is
false). - :allow_nil - Skip validation if attribute is
nil(default isfalse). Notice that for fixnum and float columns empty strings are converted tonil. - :greater_than - Specifies the value must be greater than the supplied value.
- :greater_than_or_equal_to - Specifies the value must be greater than or equal the supplied value.
- :equal_to - Specifies the value must be equal to the supplied value.
- :less_than - Specifies the value must be less than the supplied value.
- :less_than_or_equal_to - Specifies the value must be less than or equal the supplied value.
- :other_than - Specifies the value must be other than the supplied value.
- :odd - Specifies the value must be an odd number.
- :even - Specifies the value must be an even number.
There is also a list of default options supported by every validator:
:if, :unless, :on, :allow_nil, :allow_blank, and :strict .
See ActiveModel::Validation#validates for more information
The following checks can also be supplied with a proc or a symbol which corresponds to a method:
- :greater_than
- :greater_than_or_equal_to
- :equal_to
- :less_than
- :less_than_or_equal_to
For example:
class Person < ActiveRecord::Base
validates_numericality_of :width, less_than: ->(person) { person.height }
validates_numericality_of :width, greater_than: :minimum_weight
end
131 132 133 |
# File 'lib/active_model/validations/numericality.rb', line 131 def validates_numericality_of(*attr_names) validates_with NumericalityValidator, _merge_attributes(attr_names) end |